EcsError

Enum EcsError 

pub enum EcsError {
    NotInitialized,
    AlreadyBorrowed,
    DispatcherExecutionFailed(Vec<Error>),
    SystemError(Box<dyn Error + Send>),
    TypeUlidCollision,
}
The types of errors used throughout the ECS.

Variants



NotInitialized

A resource was not initialized in the World but the System tries to access it.



AlreadyBorrowed

The requested resource is already borrowed.

This error is created if the System tries to read a resource that has already been mutably borrowed. It can also happen when trying to mutably borrow a resource that is already being read.

This error should not occur during normal use, as the dispatchers can recover easily.



DispatcherExecutionFailed(Vec<Error>)

The execution of the dispatcher failed and returned one or more errors.



SystemError(Box<dyn Error + Send>)

This variant is for user-defined errors.

To create an error of this type easily, use the system_error! macro.



TypeUlidCollision

This happens when two Rust types have the same TypeUlid, which must not happen in the same World.