pub trait IntoSystem<Args, Out> {
// Required method
fn system(self) -> System<Out>;
}Expand description
Converts a function into a System.
IntoSystem is automatically implemented for all functions and closures that:
- Have 26 or less arguments,
- Where every argument implments
SystemParam, and - That returns either
()orSystemResult
IntoSystem is also implemented for functions that take &World as an argument, and
return either () or SystemResult.
The most common SystemParam types that you will use as arguments to a system will be: